@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 use LWP::UserAgent;
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 use constant {
     WHITESPACE_ONLY         => 'WHITESPACE_ONLY',
@@ -20,7 +20,7 @@ use constant {
     TEXT                    => 'text',
     JSON                    => 'json',
     XML                     => 'xml',
-    CLOSURE_COMPILER_SERVICE=>'http://closure-compiler.appspot.com/compile'
+    CLOSURE_COMPILER_SERVICE=>'https://closure-compiler.appspot.com/compile'
 };
 
 my  @compilation_level = qw(WHITESPACE_ONLY SIMPLE_OPTIMIZATIONS ADVANCED_OPTIMIZATIONS);
